Index: content/browser/zygote_host/zygote_communication_linux.cc |
diff --git a/content/browser/zygote_host/zygote_communication_linux.cc b/content/browser/zygote_host/zygote_communication_linux.cc |
index 1c2192cafdc3f56a585bb53d01213623dc91e564..88f24452d81af0f780a97e544858e9d418c3086c 100644 |
--- a/content/browser/zygote_host/zygote_communication_linux.cc |
+++ b/content/browser/zygote_host/zygote_communication_linux.cc |
@@ -84,7 +84,7 @@ ssize_t ZygoteCommunication::ReadReply(void* buf, size_t buf_len) { |
pid_t ZygoteCommunication::ForkRequest( |
const std::vector<std::string>& argv, |
- std::unique_ptr<FileDescriptorInfo> mapping, |
+ std::unique_ptr<PosixFileDescriptorInfo> mapping, |
const std::string& process_type) { |
DCHECK(init_); |
@@ -111,7 +111,7 @@ pid_t ZygoteCommunication::ForkRequest( |
// First FD to send is peer_sock. |
// TODO(morrita): Ideally, this should be part of the mapping so that |
// FileDescriptorInfo can manages its lifetime. |
fds.push_back(peer_sock.get()); |
// The rest come from mapping. |
@@ -111,7 +111,7 @@ pid_t ZygoteCommunication::ForkRequest( |
// First FD to send is peer_sock. |
// TODO(morrita): Ideally, this should be part of the mapping so that |
- // FileDescriptorInfo can manages its lifetime. |
+ // PosixFileDescriptorInfo can manages its lifetime. |
fds.push_back(peer_sock.get()); |
// The rest come from mapping. |